import { Controller, Get, Query, Post, Body } from '@nestjs/common'
import { ApiOperation, ApiTags } from '@nestjs/swagger'

import {
  GetNativeAgentListDto,
  GetNativeAgentConfigurationDto,
  SaveNativeAgentConfigurationDto
} from '@/dto/agent-list'

import { AgentListService } from './service/agent-list.service'

@ApiTags('agent-list')
@Controller('agent-list')
export class AgentListController {
  constructor(private readonly agentListService: AgentListService) {}

  @Get('native-agent-list')
  @ApiOperation({ summary: '获取原生客服列表' })
  async getNativeAgentList(@Query() query: GetNativeAgentListDto) {
    return this.agentListService.getNativeAgentList({
      page: query.page,
      page_size: query.pageSize,
      create_user: query.createUser,
      update_user: query.updateUser
    })
  }

  @Get('native-agent-configuration')
  @ApiOperation({ summary: '获取原生客服配置' })
  async getNativeAgentConfiguration(
    @Query() query: GetNativeAgentConfigurationDto
  ) {
    return this.agentListService.getNativeAgentConfiguration(query.agentId)
  }

  @Post('native-agent-configuration')
  @ApiOperation({ summary: '保存原生客服配置' })
  async saveNativeAgentConfiguration(
    @Body() body: SaveNativeAgentConfigurationDto
  ) {
    return this.agentListService.saveNativeAgentConfiguration({
      agent_id: body.agentId,
      name: body.name,
      display_name: body.displayName,
      type: body.type,
      execution_model: body.executionModel,
      system_prompt: body.systemPrompt,
      task_prompt: body.taskPrompt,
      tools: body.tools,
      sub_agents: body.subAgents,
      extra_params: body.extraParams
    })
  }

  @Get('tool-list')
  @ApiOperation({ summary: '获取工具列表' })
  async getToolList() {
    return this.agentListService.getToolList()
  }
}
