import { Injectable } from '@nestjs/common'

import { ServiceResponse } from '@/response/response.interface'
import { HttpClientService } from '@/shared/http-client/http-client.service'

@Injectable()
export class AgentServerHttpService {
  private readonly baseUrl = 'http://192.168.206.189:8083/api'

  constructor(private readonly httpClientService: HttpClientService) {}

  private async makeRequest<T>(
    endpoint: string,
    params?: Record<string, any>
  ): Promise<ServiceResponse<T>> {
    const url = `${this.baseUrl}/${endpoint}`
    return this.httpClientService.get<T>(url, params)
  }

  async makeRequestPost<T>(
    endpoint: string,
    params?: Record<string, any>
  ): Promise<ServiceResponse<T>> {
    const url = `${this.baseUrl}/${endpoint}`
    return this.httpClientService.post<T>(url, params)
  }

  async listStaffs(): Promise<ServiceResponse<StaffsType[]>> {
    return this.makeRequest<StaffsType[]>('listStaffs')
  }

  async getStaffProfile(
    staff_id: string
  ): Promise<ServiceResponse<StaffProfile>> {
    return this.makeRequest<StaffProfile>('getStaffProfile', { staff_id })
  }

  async getUserProfile(user_id: string): Promise<ServiceResponse<UserProfile>> {
    return this.makeRequest<UserProfile>('getUserProfile', { user_id })
  }

  async listUsers(
    user_name: string,
    user_union_id: string
  ): Promise<ServiceResponse<UserProfile[]>> {
    return this.makeRequest<UserProfile[]>('listUsers', {
      user_name,
      user_union_id
    })
  }

  async getDialogueHistory(
    staff_id: string,
    user_id: string,
    recent_minutes: string
  ): Promise<ServiceResponse<DialogueHistory[]>> {
    return this.makeRequest<DialogueHistory[]>('getDialogueHistory', {
      staff_id,
      user_id,
      recent_minutes
    })
  }

  async listModels(): Promise<ServiceResponse<Model[]>> {
    return this.makeRequest<Model[]>('listModels')
  }

  async listScenes(): Promise<ServiceResponse<any[]>> {
    return this.makeRequest<any[]>('listScenes')
  }

  async getBasePrompt(scene: string): Promise<ServiceResponse<string>> {
    return this.makeRequest<string>('getBasePrompt', { scene })
  }

  async runPrompt(params: any): Promise<ServiceResponse<any>> {
    return this.makeRequestPost<any>('runPrompt', params)
  }

  async formatForPrompt(params: any): Promise<ServiceResponse<any>> {
    return this.makeRequestPost<any>('formatForPrompt', params)
  }
}
